@@ -31,6 +31,10 @@
 #include <malloc.h>
 #include <config.h>
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #ifdef HAVE_GETOPT_H
   #include <getopt.h>
 #endif
@@ -38,11 +42,11 @@
 char version_man[] = "asn1Parser (GNU libasn1) " VERSION;
 
 char help_man[] = "asn1Parser reads files with ASN1 definitions and\n"
-                  "generates a C array to use with libasn1 functions.\n"
+                  "generates a C array to use with libtasn1 functions.\n"
                   "\n"
                   "Usage: asn1Parser [options] file\n"
                   "\n"
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
                   "Operation modes:\n"
                   "  -h, --help    shows this message and exit\n"
                   "  -v, --version shows version information and exit.\n"
@@ -70,7 +74,7 @@ int
 main(int argc,char *argv[])
 {
 
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
   static struct option long_options[] =
   {
     {"help",    no_argument,       0, 'h'},
@@ -80,10 +84,10 @@ main(int argc,char *argv[])
     {"name",    required_argument, 0, 'n'},
     {0, 0, 0, 0}
   };
+  int option_index = 0;
 #endif
 
  int option_result;
- int option_index = 0;
  char *outputFileName=NULL;
  char *inputFileName=NULL;
  char *vectorName=NULL;
@@ -98,7 +102,7 @@ main(int argc,char *argv[])
 
  while(1){
 
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
    option_result=getopt_long(argc,argv,"hvco:n:",long_options,&option_index);
 #else
    option_result=getopt(argc,argv,"hvco:n:");
@@ -108,7 +112,7 @@ main(int argc,char *argv[])
 
    switch(option_result){
    case 0:
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
      printf("option %s",long_options[option_index].name);
      if(optarg) printf(" with arg %s",optarg);
      printf("\n");
@@ -187,7 +191,7 @@ main(int argc,char *argv[])
    printf("asn1Parser: %s\n",errorDescription);
    break;
  default:
-   printf("libasn1 ERROR: %s\n",libasn1_strerror(parse_result));
+   printf("libasn1 ERROR: %s\n",libtasn1_strerror(parse_result));
  }
 
 
